Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2Config
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2Config
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
Represents an Identity Toolkit project.
Instance Attribute Summary collapse
-
#authorized_domains ⇒ Array<String>
List of domains authorized for OAuth redirects Corresponds to the JSON property
authorizedDomains. -
#autodelete_anonymous_users ⇒ Boolean
(also: #autodelete_anonymous_users?)
Whether anonymous users will be auto-deleted after a period of 30 days.
-
#blocking_functions ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2BlockingFunctionsConfig
Configuration related to Blocking Functions.
-
#client ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2ClientConfig
Options related to how clients making requests on behalf of a project should be configured.
-
#default_hosting_site ⇒ String
Output only.
-
#email_privacy_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailPrivacyConfig
Configuration for settings related to email privacy and public visibility.
-
#mfa ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig
Options related to MultiFactor Authentication for the project.
-
#mobile_links_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MobileLinksConfig
Configuration mobile links.
-
#monitoring ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MonitoringConfig
Configuration related to monitoring project activity.
-
#multi_tenant ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MultiTenantConfig
Configuration related to multi-tenant functionality.
-
#name ⇒ String
Output only.
-
#notification ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2NotificationConfig
Configuration related to sending notifications to users.
-
#password_policy_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2PasswordPolicyConfig
The configuration for the password policy on the project.
-
#quota ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2QuotaConfig
Configuration related to quotas.
-
#recaptcha_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2RecaptchaConfig
The reCAPTCHA Enterprise integration config.
-
#sign_in ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2SignInConfig
Configuration related to local sign in methods.
-
#sms_region_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig
Configures the regions where users are allowed to send verification SMS for the project or tenant.
-
#subtype ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2Config
constructor
A new instance of GoogleCloudIdentitytoolkitAdminV2Config.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2Config
Returns a new instance of GoogleCloudIdentitytoolkitAdminV2Config.
353 354 355 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 353 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorized_domains ⇒ Array<String>
List of domains authorized for OAuth redirects
Corresponds to the JSON property authorizedDomains
259 260 261 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 259 def @authorized_domains end |
#autodelete_anonymous_users ⇒ Boolean Also known as: autodelete_anonymous_users?
Whether anonymous users will be auto-deleted after a period of 30 days.
Corresponds to the JSON property autodeleteAnonymousUsers
264 265 266 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 264 def autodelete_anonymous_users @autodelete_anonymous_users end |
#blocking_functions ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2BlockingFunctionsConfig
Configuration related to Blocking Functions.
Corresponds to the JSON property blockingFunctions
270 271 272 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 270 def blocking_functions @blocking_functions end |
#client ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2ClientConfig
Options related to how clients making requests on behalf of a project should
be configured.
Corresponds to the JSON property client
276 277 278 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 276 def client @client end |
#default_hosting_site ⇒ String
Output only. Default Firebase hosting site name
Corresponds to the JSON property defaultHostingSite
281 282 283 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 281 def default_hosting_site @default_hosting_site end |
#email_privacy_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailPrivacyConfig
Configuration for settings related to email privacy and public visibility.
Settings in this config protect against email enumeration, but may make some
trade-offs in user-friendliness.
Corresponds to the JSON property emailPrivacyConfig
288 289 290 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 288 def email_privacy_config @email_privacy_config end |
#mfa ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig
Options related to MultiFactor Authentication for the project.
Corresponds to the JSON property mfa
293 294 295 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 293 def mfa @mfa end |
#mobile_links_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MobileLinksConfig
Configuration mobile links.
Corresponds to the JSON property mobileLinksConfig
298 299 300 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 298 def mobile_links_config @mobile_links_config end |
#monitoring ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MonitoringConfig
Configuration related to monitoring project activity.
Corresponds to the JSON property monitoring
303 304 305 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 303 def monitoring @monitoring end |
#multi_tenant ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MultiTenantConfig
Configuration related to multi-tenant functionality.
Corresponds to the JSON property multiTenant
308 309 310 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 308 def multi_tenant @multi_tenant end |
#name ⇒ String
Output only. The name of the Config resource. Example: "projects/my-awesome-
project/config"
Corresponds to the JSON property name
314 315 316 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 314 def name @name end |
#notification ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2NotificationConfig
Configuration related to sending notifications to users.
Corresponds to the JSON property notification
319 320 321 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 319 def notification @notification end |
#password_policy_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2PasswordPolicyConfig
The configuration for the password policy on the project.
Corresponds to the JSON property passwordPolicyConfig
324 325 326 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 324 def password_policy_config @password_policy_config end |
#quota ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2QuotaConfig
Configuration related to quotas.
Corresponds to the JSON property quota
329 330 331 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 329 def quota @quota end |
#recaptcha_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2RecaptchaConfig
The reCAPTCHA Enterprise integration config.
Corresponds to the JSON property recaptchaConfig
334 335 336 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 334 def recaptcha_config @recaptcha_config end |
#sign_in ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2SignInConfig
Configuration related to local sign in methods.
Corresponds to the JSON property signIn
339 340 341 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 339 def sign_in @sign_in end |
#sms_region_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig
Configures the regions where users are allowed to send verification SMS for
the project or tenant. This is based on the calling code of the destination
phone number.
Corresponds to the JSON property smsRegionConfig
346 347 348 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 346 def sms_region_config @sms_region_config end |
#subtype ⇒ String
Output only. The subtype of this config.
Corresponds to the JSON property subtype
351 352 353 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 351 def subtype @subtype end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 358 def update!(**args) @authorized_domains = args[:authorized_domains] if args.key?(:authorized_domains) @autodelete_anonymous_users = args[:autodelete_anonymous_users] if args.key?(:autodelete_anonymous_users) @blocking_functions = args[:blocking_functions] if args.key?(:blocking_functions) @client = args[:client] if args.key?(:client) @default_hosting_site = args[:default_hosting_site] if args.key?(:default_hosting_site) @email_privacy_config = args[:email_privacy_config] if args.key?(:email_privacy_config) @mfa = args[:mfa] if args.key?(:mfa) @mobile_links_config = args[:mobile_links_config] if args.key?(:mobile_links_config) @monitoring = args[:monitoring] if args.key?(:monitoring) @multi_tenant = args[:multi_tenant] if args.key?(:multi_tenant) @name = args[:name] if args.key?(:name) @notification = args[:notification] if args.key?(:notification) @password_policy_config = args[:password_policy_config] if args.key?(:password_policy_config) @quota = args[:quota] if args.key?(:quota) @recaptcha_config = args[:recaptcha_config] if args.key?(:recaptcha_config) @sign_in = args[:sign_in] if args.key?(:sign_in) @sms_region_config = args[:sms_region_config] if args.key?(:sms_region_config) @subtype = args[:subtype] if args.key?(:subtype) end |