Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2DnsInfo
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2DnsInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
Information of custom domain DNS verification. By default, default_domain will be used. A custom domain can be configured using VerifyCustomDomain.
Instance Attribute Summary collapse
-
#custom_domain ⇒ String
Output only.
-
#custom_domain_state ⇒ String
Output only.
-
#domain_verification_request_time ⇒ String
Output only.
-
#pending_custom_domain ⇒ String
Output only.
-
#use_custom_domain ⇒ Boolean
(also: #use_custom_domain?)
Whether to use custom domain.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2DnsInfo
constructor
A new instance of GoogleCloudIdentitytoolkitAdminV2DnsInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2DnsInfo
Returns a new instance of GoogleCloudIdentitytoolkitAdminV2DnsInfo.
537 538 539 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 537 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_domain ⇒ String
Output only. The applied verified custom domain.
Corresponds to the JSON property customDomain
512 513 514 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 512 def custom_domain @custom_domain end |
#custom_domain_state ⇒ String
Output only. The current verification state of the custom domain. The custom
domain will only be used once the domain verification is successful.
Corresponds to the JSON property customDomainState
518 519 520 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 518 def custom_domain_state @custom_domain_state end |
#domain_verification_request_time ⇒ String
Output only. The timestamp of initial request for the current domain
verification.
Corresponds to the JSON property domainVerificationRequestTime
524 525 526 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 524 def domain_verification_request_time @domain_verification_request_time end |
#pending_custom_domain ⇒ String
Output only. The custom domain that's to be verified.
Corresponds to the JSON property pendingCustomDomain
529 530 531 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 529 def pending_custom_domain @pending_custom_domain end |
#use_custom_domain ⇒ Boolean Also known as: use_custom_domain?
Whether to use custom domain.
Corresponds to the JSON property useCustomDomain
534 535 536 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 534 def use_custom_domain @use_custom_domain end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
542 543 544 545 546 547 548 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 542 def update!(**args) @custom_domain = args[:custom_domain] if args.key?(:custom_domain) @custom_domain_state = args[:custom_domain_state] if args.key?(:custom_domain_state) @domain_verification_request_time = args[:domain_verification_request_time] if args.key?(:domain_verification_request_time) @pending_custom_domain = args[:pending_custom_domain] if args.key?(:pending_custom_domain) @use_custom_domain = args[:use_custom_domain] if args.key?(:use_custom_domain) end |