Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailPrivacyConfig
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailPrivacyConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
Configuration for settings related to email privacy and public visibility. Settings in this config protect against email enumeration, but may make some trade-offs in user-friendliness.
Instance Attribute Summary collapse
-
#enable_improved_email_privacy ⇒ Boolean
(also: #enable_improved_email_privacy?)
Migrates the project to a state of improved email privacy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2EmailPrivacyConfig
constructor
A new instance of GoogleCloudIdentitytoolkitAdminV2EmailPrivacyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2EmailPrivacyConfig
Returns a new instance of GoogleCloudIdentitytoolkitAdminV2EmailPrivacyConfig.
598 599 600 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 598 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_improved_email_privacy ⇒ Boolean Also known as: enable_improved_email_privacy?
Migrates the project to a state of improved email privacy. For example certain
error codes are more generic to avoid giving away information on whether the
account exists. In addition, this disables certain features that as a side-
effect allow user enumeration. Enabling this toggle disables the
fetchSignInMethodsForEmail functionality and changing the user's email to an
unverified email. It is recommended to remove dependence on this functionality
and enable this toggle to improve user privacy.
Corresponds to the JSON property enableImprovedEmailPrivacy
595 596 597 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 595 def enable_improved_email_privacy @enable_improved_email_privacy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
603 604 605 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 603 def update!(**args) @enable_improved_email_privacy = args[:enable_improved_email_privacy] if args.key?(:enable_improved_email_privacy) end |