Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2HashConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb

Overview

History information of the hash algorithm and key. Different accounts' passwords may be generated by different version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2HashConfig

Returns a new instance of GoogleCloudIdentitytoolkitAdminV2HashConfig.



737
738
739
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 737

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#algorithmString

Output only. Different password hash algorithms used in Identity Toolkit. Corresponds to the JSON property algorithm

Returns:

  • (String)


711
712
713
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 711

def algorithm
  @algorithm
end

#memory_costFixnum

Output only. Memory cost for hash calculation. Used by scrypt and other similar password derivation algorithms. See https://tools.ietf.org/html/ rfc7914 for explanation of field. Corresponds to the JSON property memoryCost

Returns:

  • (Fixnum)


718
719
720
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 718

def memory_cost
  @memory_cost
end

#roundsFixnum

Output only. How many rounds for hash calculation. Used by scrypt and other similar password derivation algorithms. Corresponds to the JSON property rounds

Returns:

  • (Fixnum)


724
725
726
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 724

def rounds
  @rounds
end

#salt_separatorString

Output only. Non-printable character to be inserted between the salt and plain text password in base64. Corresponds to the JSON property saltSeparator

Returns:

  • (String)


730
731
732
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 730

def salt_separator
  @salt_separator
end

#signer_keyString

Output only. Signer key in base64. Corresponds to the JSON property signerKey

Returns:

  • (String)


735
736
737
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 735

def signer_key
  @signer_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



742
743
744
745
746
747
748
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 742

def update!(**args)
  @algorithm = args[:algorithm] if args.key?(:algorithm)
  @memory_cost = args[:memory_cost] if args.key?(:memory_cost)
  @rounds = args[:rounds] if args.key?(:rounds)
  @salt_separator = args[:salt_separator] if args.key?(:salt_separator)
  @signer_key = args[:signer_key] if args.key?(:signer_key)
end