Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2InboundSamlConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb

Overview

A pair of SAML RP-IDP configurations when the project acts as the relying party.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2InboundSamlConfig

Returns a new instance of GoogleCloudIdentitytoolkitAdminV2InboundSamlConfig.



845
846
847
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 845

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The config's display name set by developers. Corresponds to the JSON property displayName

Returns:

  • (String)


818
819
820
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 818

def display_name
  @display_name
end

#enabledBoolean Also known as: enabled?

True if allows the user to sign in with the provider. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


823
824
825
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 823

def enabled
  @enabled
end

#idp_configGoogle::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2IdpConfig

The SAML IdP (Identity Provider) configuration when the project acts as the relying party. Corresponds to the JSON property idpConfig



830
831
832
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 830

def idp_config
  @idp_config
end

#nameString

The name of the InboundSamlConfig resource, for example: 'projects/my-awesome- project/inboundSamlConfigs/my-config-id'. Ignored during create requests. Corresponds to the JSON property name

Returns:

  • (String)


836
837
838
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 836

def name
  @name
end

#sp_configGoogle::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2SpConfig

The SAML SP (Service Provider) configuration when the project acts as the relying party to receive and accept an authentication assertion issued by a SAML identity provider. Corresponds to the JSON property spConfig



843
844
845
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 843

def sp_config
  @sp_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



850
851
852
853
854
855
856
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 850

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enabled = args[:enabled] if args.key?(:enabled)
  @idp_config = args[:idp_config] if args.key?(:idp_config)
  @name = args[:name] if args.key?(:name)
  @sp_config = args[:sp_config] if args.key?(:sp_config)
end