Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb

Overview

Response for ListInboundSamlConfigs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponse

Returns a new instance of GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponse.



975
976
977
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inbound_saml_configsArray<Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2InboundSamlConfig>

The set of configs. Corresponds to the JSON property inboundSamlConfigs



967
968
969
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 967

def inbound_saml_configs
  @inbound_saml_configs
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


973
974
975
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 973

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



980
981
982
983
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 980

def update!(**args)
  @inbound_saml_configs = args[:inbound_saml_configs] if args.key?(:inbound_saml_configs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end