Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MobileLinksConfig
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MobileLinksConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
Configuration mobile links.
Instance Attribute Summary collapse
-
#domain ⇒ String
Open code in app domain to use for app links and universal links.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2MobileLinksConfig
constructor
A new instance of GoogleCloudIdentitytoolkitAdminV2MobileLinksConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2MobileLinksConfig
Returns a new instance of GoogleCloudIdentitytoolkitAdminV2MobileLinksConfig.
1046 1047 1048 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
Open code in app domain to use for app links and universal links.
Corresponds to the JSON property domain
1044 1045 1046 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1044 def domain @domain end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1051 1052 1053 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1051 def update!(**args) @domain = args[:domain] if args.key?(:domain) end |