Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2PasswordPolicyConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb

Overview

The configuration for the password policy on the project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2PasswordPolicyConfig

Returns a new instance of GoogleCloudIdentitytoolkitAdminV2PasswordPolicyConfig.



1292
1293
1294
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#force_upgrade_on_signinBoolean Also known as: force_upgrade_on_signin?

Users must have a password compliant with the password policy to sign-in. Corresponds to the JSON property forceUpgradeOnSignin

Returns:

  • (Boolean)


1274
1275
1276
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1274

def 
  @force_upgrade_on_signin
end

#last_update_timeString

Output only. The last time the password policy on the project was updated. Corresponds to the JSON property lastUpdateTime

Returns:

  • (String)


1280
1281
1282
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1280

def last_update_time
  @last_update_time
end

#password_policy_enforcement_stateString

Which enforcement mode to use for the password policy. Corresponds to the JSON property passwordPolicyEnforcementState

Returns:

  • (String)


1285
1286
1287
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1285

def password_policy_enforcement_state
  @password_policy_enforcement_state
end

#password_policy_versionsArray<Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2PasswordPolicyVersion>

Must be of length 1. Contains the strength attributes for the password policy. Corresponds to the JSON property passwordPolicyVersions



1290
1291
1292
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1290

def password_policy_versions
  @password_policy_versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1297
1298
1299
1300
1301
1302
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1297

def update!(**args)
  @force_upgrade_on_signin = args[:force_upgrade_on_signin] if args.key?(:force_upgrade_on_signin)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
  @password_policy_enforcement_state = args[:password_policy_enforcement_state] if args.key?(:password_policy_enforcement_state)
  @password_policy_versions = args[:password_policy_versions] if args.key?(:password_policy_versions)
end