Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2CustomStrengthOptions
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2CustomStrengthOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
Custom strength options to enforce on user passwords.
Instance Attribute Summary collapse
-
#contains_lowercase_character ⇒ Boolean
(also: #contains_lowercase_character?)
The password must contain a lower case character.
-
#contains_non_alphanumeric_character ⇒ Boolean
(also: #contains_non_alphanumeric_character?)
The password must contain a non alpha numeric character.
-
#contains_numeric_character ⇒ Boolean
(also: #contains_numeric_character?)
The password must contain a number.
-
#contains_uppercase_character ⇒ Boolean
(also: #contains_uppercase_character?)
The password must contain an upper case character.
-
#max_password_length ⇒ Fixnum
Maximum password length.
-
#min_password_length ⇒ Fixnum
Minimum password length.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2CustomStrengthOptions
constructor
A new instance of GoogleCloudIdentitytoolkitV2CustomStrengthOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2CustomStrengthOptions
Returns a new instance of GoogleCloudIdentitytoolkitV2CustomStrengthOptions.
2212 2213 2214 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2212 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contains_lowercase_character ⇒ Boolean Also known as: contains_lowercase_character?
The password must contain a lower case character.
Corresponds to the JSON property containsLowercaseCharacter
2181 2182 2183 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2181 def contains_lowercase_character @contains_lowercase_character end |
#contains_non_alphanumeric_character ⇒ Boolean Also known as: contains_non_alphanumeric_character?
The password must contain a non alpha numeric character.
Corresponds to the JSON property containsNonAlphanumericCharacter
2187 2188 2189 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2187 def contains_non_alphanumeric_character @contains_non_alphanumeric_character end |
#contains_numeric_character ⇒ Boolean Also known as: contains_numeric_character?
The password must contain a number.
Corresponds to the JSON property containsNumericCharacter
2193 2194 2195 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2193 def contains_numeric_character @contains_numeric_character end |
#contains_uppercase_character ⇒ Boolean Also known as: contains_uppercase_character?
The password must contain an upper case character.
Corresponds to the JSON property containsUppercaseCharacter
2199 2200 2201 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2199 def contains_uppercase_character @contains_uppercase_character end |
#max_password_length ⇒ Fixnum
Maximum password length. No default max length
Corresponds to the JSON property maxPasswordLength
2205 2206 2207 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2205 def max_password_length @max_password_length end |
#min_password_length ⇒ Fixnum
Minimum password length. Range from 6 to 30
Corresponds to the JSON property minPasswordLength
2210 2211 2212 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2210 def min_password_length @min_password_length end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2217 2218 2219 2220 2221 2222 2223 2224 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2217 def update!(**args) @contains_lowercase_character = args[:contains_lowercase_character] if args.key?(:contains_lowercase_character) @contains_non_alphanumeric_character = args[:contains_non_alphanumeric_character] if args.key?(:contains_non_alphanumeric_character) @contains_numeric_character = args[:contains_numeric_character] if args.key?(:contains_numeric_character) @contains_uppercase_character = args[:contains_uppercase_character] if args.key?(:contains_uppercase_character) @max_password_length = args[:max_password_length] if args.key?(:max_password_length) @min_password_length = args[:min_password_length] if args.key?(:min_password_length) end |