Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2FinalizeMfaEnrollmentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb

Overview

Finishes enrolling a second factor for the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2FinalizeMfaEnrollmentRequest

Returns a new instance of GoogleCloudIdentitytoolkitV2FinalizeMfaEnrollmentRequest.



2258
2259
2260
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2258

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Display name which is entered by users to distinguish between different second factors with same type or different type. Corresponds to the JSON property displayName

Returns:

  • (String)


2235
2236
2237
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2235

def display_name
  @display_name
end

#id_tokenString

Required. ID token. Corresponds to the JSON property idToken

Returns:

  • (String)


2240
2241
2242
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2240

def id_token
  @id_token
end

#phone_verification_infoGoogle::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2FinalizeMfaPhoneRequestInfo

Phone Verification info for a FinalizeMfa request. Corresponds to the JSON property phoneVerificationInfo



2245
2246
2247
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2245

def phone_verification_info
  @phone_verification_info
end

#tenant_idString

The ID of the Identity Platform tenant that the user enrolling MFA belongs to. If not set, the user belongs to the default Identity Platform project. Corresponds to the JSON property tenantId

Returns:

  • (String)


2251
2252
2253
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2251

def tenant_id
  @tenant_id
end

#totp_verification_infoGoogle::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2FinalizeMfaTotpEnrollmentRequestInfo

Mfa request info specific to TOTP auth for FinalizeMfa. Corresponds to the JSON property totpVerificationInfo



2256
2257
2258
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2256

def totp_verification_info
  @totp_verification_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2263
2264
2265
2266
2267
2268
2269
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2263

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id_token = args[:id_token] if args.key?(:id_token)
  @phone_verification_info = args[:phone_verification_info] if args.key?(:phone_verification_info)
  @tenant_id = args[:tenant_id] if args.key?(:tenant_id)
  @totp_verification_info = args[:totp_verification_info] if args.key?(:totp_verification_info)
end