Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2PasswordPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb

Overview

Configuration for password policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2PasswordPolicy

Returns a new instance of GoogleCloudIdentitytoolkitV2PasswordPolicy.



2539
2540
2541
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_non_alphanumeric_charactersArray<String>

Output only. Allowed characters which satisfy the non_alphanumeric requirement. Corresponds to the JSON property allowedNonAlphanumericCharacters

Returns:

  • (Array<String>)


2516
2517
2518
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2516

def allowed_non_alphanumeric_characters
  @allowed_non_alphanumeric_characters
end

#custom_strength_optionsGoogle::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2CustomStrengthOptions

Custom strength options to enforce on user passwords. Corresponds to the JSON property customStrengthOptions



2521
2522
2523
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2521

def custom_strength_options
  @custom_strength_options
end

#enforcement_stateString

Output only. Which enforcement mode to use for the password policy. Corresponds to the JSON property enforcementState

Returns:

  • (String)


2526
2527
2528
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2526

def enforcement_state
  @enforcement_state
end

#force_upgrade_on_signinBoolean Also known as: force_upgrade_on_signin?

Users must have a password compliant with the password policy to sign-in. Corresponds to the JSON property forceUpgradeOnSignin

Returns:

  • (Boolean)


2531
2532
2533
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2531

def 
  @force_upgrade_on_signin
end

#schema_versionFixnum

Output only. schema version number for the password policy Corresponds to the JSON property schemaVersion

Returns:

  • (Fixnum)


2537
2538
2539
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2537

def schema_version
  @schema_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2544
2545
2546
2547
2548
2549
2550
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2544

def update!(**args)
  @allowed_non_alphanumeric_characters = args[:allowed_non_alphanumeric_characters] if args.key?(:allowed_non_alphanumeric_characters)
  @custom_strength_options = args[:custom_strength_options] if args.key?(:custom_strength_options)
  @enforcement_state = args[:enforcement_state] if args.key?(:enforcement_state)
  @force_upgrade_on_signin = args[:force_upgrade_on_signin] if args.key?(:force_upgrade_on_signin)
  @schema_version = args[:schema_version] if args.key?(:schema_version)
end