Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2RecaptchaConfig
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2RecaptchaConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
Configuration for reCAPTCHA
Instance Attribute Summary collapse
-
#recaptcha_enforcement_state ⇒ Array<Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2RecaptchaEnforcementState>
The reCAPTCHA enforcement state for the providers that GCIP supports reCAPTCHA protection.
-
#recaptcha_key ⇒ String
The reCAPTCHA Enterprise key resource name, e.g.
-
#use_sms_bot_score ⇒ Boolean
(also: #use_sms_bot_score?)
Whether to use the rCE bot score for reCAPTCHA phone provider.
-
#use_sms_toll_fraud_protection ⇒ Boolean
(also: #use_sms_toll_fraud_protection?)
Whether to use the rCE sms toll fraud protection risk score for reCAPTCHA phone provider.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2RecaptchaConfig
constructor
A new instance of GoogleCloudIdentitytoolkitV2RecaptchaConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2RecaptchaConfig
Returns a new instance of GoogleCloudIdentitytoolkitV2RecaptchaConfig.
2583 2584 2585 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#recaptcha_enforcement_state ⇒ Array<Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2RecaptchaEnforcementState>
The reCAPTCHA enforcement state for the providers that GCIP supports reCAPTCHA
protection.
Corresponds to the JSON property recaptchaEnforcementState
2561 2562 2563 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2561 def recaptcha_enforcement_state @recaptcha_enforcement_state end |
#recaptcha_key ⇒ String
The reCAPTCHA Enterprise key resource name, e.g. "projects/project/keys/key
". This will only be returned when the reCAPTCHA enforcement state is AUDIT or
ENFORCE on at least one of the reCAPTCHA providers.
Corresponds to the JSON property recaptchaKey
2568 2569 2570 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2568 def recaptcha_key @recaptcha_key end |
#use_sms_bot_score ⇒ Boolean Also known as: use_sms_bot_score?
Whether to use the rCE bot score for reCAPTCHA phone provider.
Corresponds to the JSON property useSmsBotScore
2573 2574 2575 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2573 def use_sms_bot_score @use_sms_bot_score end |
#use_sms_toll_fraud_protection ⇒ Boolean Also known as: use_sms_toll_fraud_protection?
Whether to use the rCE sms toll fraud protection risk score for reCAPTCHA
phone provider.
Corresponds to the JSON property useSmsTollFraudProtection
2580 2581 2582 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2580 def use_sms_toll_fraud_protection @use_sms_toll_fraud_protection end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2588 2589 2590 2591 2592 2593 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2588 def update!(**args) @recaptcha_enforcement_state = args[:recaptcha_enforcement_state] if args.key?(:recaptcha_enforcement_state) @recaptcha_key = args[:recaptcha_key] if args.key?(:recaptcha_key) @use_sms_bot_score = args[:use_sms_bot_score] if args.key?(:use_sms_bot_score) @use_sms_toll_fraud_protection = args[:use_sms_toll_fraud_protection] if args.key?(:use_sms_toll_fraud_protection) end |