Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2StartMfaEnrollmentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb

Overview

Sends MFA enrollment verification SMS for a user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2StartMfaEnrollmentRequest

Returns a new instance of GoogleCloudIdentitytoolkitV2StartMfaEnrollmentRequest.



2717
2718
2719
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2717

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#id_tokenString

Required. User's ID token. Corresponds to the JSON property idToken

Returns:

  • (String)


2699
2700
2701
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2699

def id_token
  @id_token
end

#phone_enrollment_infoGoogle::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2StartMfaPhoneRequestInfo

App Verification info for a StartMfa request. Corresponds to the JSON property phoneEnrollmentInfo



2704
2705
2706
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2704

def phone_enrollment_info
  @phone_enrollment_info
end

#tenant_idString

The ID of the Identity Platform tenant that the user enrolling MFA belongs to. If not set, the user belongs to the default Identity Platform project. Corresponds to the JSON property tenantId

Returns:

  • (String)


2710
2711
2712
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2710

def tenant_id
  @tenant_id
end

#totp_enrollment_infoGoogle::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2StartMfaTotpEnrollmentRequestInfo

Mfa request info specific to TOTP auth for StartMfa. Corresponds to the JSON property totpEnrollmentInfo



2715
2716
2717
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2715

def totp_enrollment_info
  @totp_enrollment_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2722
2723
2724
2725
2726
2727
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2722

def update!(**args)
  @id_token = args[:id_token] if args.key?(:id_token)
  @phone_enrollment_info = args[:phone_enrollment_info] if args.key?(:phone_enrollment_info)
  @tenant_id = args[:tenant_id] if args.key?(:tenant_id)
  @totp_enrollment_info = args[:totp_enrollment_info] if args.key?(:totp_enrollment_info)
end