Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2StartMfaPhoneRequestInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb

Overview

App Verification info for a StartMfa request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2StartMfaPhoneRequestInfo

Returns a new instance of GoogleCloudIdentitytoolkitV2StartMfaPhoneRequestInfo.



2818
2819
2820
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_retrieval_infoGoogle::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2AutoRetrievalInfo

The information required to auto-retrieve an SMS. Corresponds to the JSON property autoRetrievalInfo



2762
2763
2764
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2762

def auto_retrieval_info
  @auto_retrieval_info
end

#captcha_responseString

The reCAPTCHA Enterprise token provided by the reCAPTCHA client-side integration. Required when reCAPTCHA enterprise is enabled. Corresponds to the JSON property captchaResponse

Returns:

  • (String)


2768
2769
2770
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2768

def captcha_response
  @captcha_response
end

#client_typeString

The client type, web, android or ios. Required when reCAPTCHA Enterprise is enabled. Corresponds to the JSON property clientType

Returns:

  • (String)


2774
2775
2776
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2774

def client_type
  @client_type
end

#ios_receiptString

iOS only. Receipt of successful app token validation with APNS. Corresponds to the JSON property iosReceipt

Returns:

  • (String)


2779
2780
2781
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2779

def ios_receipt
  @ios_receipt
end

#ios_secretString

iOS only. Secret delivered to iOS app via APNS. Corresponds to the JSON property iosSecret

Returns:

  • (String)


2784
2785
2786
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2784

def ios_secret
  @ios_secret
end

#phone_numberString

Required for enrollment. Phone number to be enrolled as MFA. Corresponds to the JSON property phoneNumber

Returns:

  • (String)


2789
2790
2791
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2789

def phone_number
  @phone_number
end

#play_integrity_tokenString

Android only. Used to assert application identity in place of a recaptcha token (or safety net token). A Play Integrity Token can be generated via the PlayIntegrity API with applying SHA256 to the phone_number field as the nonce. Corresponds to the JSON property playIntegrityToken

Returns:

  • (String)


2797
2798
2799
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2797

def play_integrity_token
  @play_integrity_token
end

#recaptcha_tokenString

Web only. Recaptcha solution. Corresponds to the JSON property recaptchaToken

Returns:

  • (String)


2802
2803
2804
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2802

def recaptcha_token
  @recaptcha_token
end

#recaptcha_versionString

The reCAPTCHA version of the reCAPTCHA token in the captcha_response. Required when reCAPTCHA Enterprise is enabled. Corresponds to the JSON property recaptchaVersion

Returns:

  • (String)


2808
2809
2810
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2808

def recaptcha_version
  @recaptcha_version
end

#safety_net_tokenString

Android only. Used to assert application identity in place of a recaptcha token. A SafetyNet Token can be generated via the SafetyNet Android Attestation API, with the Base64 encoding of the phone_number field as the nonce. Corresponds to the JSON property safetyNetToken

Returns:

  • (String)


2816
2817
2818
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2816

def safety_net_token
  @safety_net_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2823

def update!(**args)
  @auto_retrieval_info = args[:auto_retrieval_info] if args.key?(:auto_retrieval_info)
  @captcha_response = args[:captcha_response] if args.key?(:captcha_response)
  @client_type = args[:client_type] if args.key?(:client_type)
  @ios_receipt = args[:ios_receipt] if args.key?(:ios_receipt)
  @ios_secret = args[:ios_secret] if args.key?(:ios_secret)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
  @play_integrity_token = args[:play_integrity_token] if args.key?(:play_integrity_token)
  @recaptcha_token = args[:recaptcha_token] if args.key?(:recaptcha_token)
  @recaptcha_version = args[:recaptcha_version] if args.key?(:recaptcha_version)
  @safety_net_token = args[:safety_net_token] if args.key?(:safety_net_token)
end