Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2WithdrawMfaRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb

Overview

Withdraws MFA.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2WithdrawMfaRequest

Returns a new instance of GoogleCloudIdentitytoolkitV2WithdrawMfaRequest.



2999
3000
3001
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#id_tokenString

Required. User's ID token. Corresponds to the JSON property idToken

Returns:

  • (String)


2986
2987
2988
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2986

def id_token
  @id_token
end

#mfa_enrollment_idString

Required. MFA enrollment id from a current MFA enrollment. Corresponds to the JSON property mfaEnrollmentId

Returns:

  • (String)


2991
2992
2993
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2991

def mfa_enrollment_id
  @mfa_enrollment_id
end

#tenant_idString

The ID of the Identity Platform tenant that the user unenrolling MFA belongs to. If not set, the user belongs to the default Identity Platform project. Corresponds to the JSON property tenantId

Returns:

  • (String)


2997
2998
2999
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2997

def tenant_id
  @tenant_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3004
3005
3006
3007
3008
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 3004

def update!(**args)
  @id_token = args[:id_token] if args.key?(:id_token)
  @mfa_enrollment_id = args[:mfa_enrollment_id] if args.key?(:mfa_enrollment_id)
  @tenant_id = args[:tenant_id] if args.key?(:tenant_id)
end