Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
Options related to MultiFactor Authentication for the project.
Instance Attribute Summary collapse
-
#enabled_providers ⇒ Array<String>
A list of usable second factors for this project.
-
#provider_configs ⇒ Array<Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2ProviderConfig>
A list of usable second factors for this project along with their configurations.
-
#state ⇒ String
Whether MultiFactor Authentication has been enabled for this project.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig
constructor
A new instance of GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig
Returns a new instance of GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig.
1096 1097 1098 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1096 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_providers ⇒ Array<String>
A list of usable second factors for this project.
Corresponds to the JSON property enabledProviders
1082 1083 1084 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1082 def enabled_providers @enabled_providers end |
#provider_configs ⇒ Array<Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2ProviderConfig>
A list of usable second factors for this project along with their
configurations. This field does not support phone based MFA, for that use the '
enabled_providers' field.
Corresponds to the JSON property providerConfigs
1089 1090 1091 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1089 def provider_configs @provider_configs end |
#state ⇒ String
Whether MultiFactor Authentication has been enabled for this project.
Corresponds to the JSON property state
1094 1095 1096 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1094 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1101 1102 1103 1104 1105 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1101 def update!(**args) @enabled_providers = args[:enabled_providers] if args.key?(:enabled_providers) @provider_configs = args[:provider_configs] if args.key?(:provider_configs) @state = args[:state] if args.key?(:state) end |