Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2RecaptchaConfig
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2RecaptchaConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
The reCAPTCHA Enterprise integration config.
Instance Attribute Summary collapse
-
#email_password_enforcement_state ⇒ String
The reCAPTCHA config for email/password provider, containing the enforcement status.
-
#managed_rules ⇒ Array<Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2RecaptchaManagedRule>
The managed rules for authentication action based on reCAPTCHA scores.
-
#phone_enforcement_state ⇒ String
The reCAPTCHA config for phone provider, containing the enforcement status.
-
#recaptcha_keys ⇒ Array<Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2RecaptchaKey>
The reCAPTCHA keys.
-
#toll_fraud_managed_rules ⇒ Array<Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2RecaptchaTollFraudManagedRule>
The managed rules for the authentication action based on reCAPTCHA toll fraud risk scores.
-
#use_account_defender ⇒ Boolean
(also: #use_account_defender?)
Whether to use the account defender for reCAPTCHA assessment.
-
#use_sms_bot_score ⇒ Boolean
(also: #use_sms_bot_score?)
Whether to use the rCE bot score for reCAPTCHA phone provider.
-
#use_sms_toll_fraud_protection ⇒ Boolean
(also: #use_sms_toll_fraud_protection?)
Whether to use the rCE sms toll fraud protection risk score for reCAPTCHA phone provider.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2RecaptchaConfig
constructor
A new instance of GoogleCloudIdentitytoolkitAdminV2RecaptchaConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2RecaptchaConfig
Returns a new instance of GoogleCloudIdentitytoolkitAdminV2RecaptchaConfig.
1488 1489 1490 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1488 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email_password_enforcement_state ⇒ String
The reCAPTCHA config for email/password provider, containing the enforcement
status. The email/password provider contains all email related user flows
protected by reCAPTCHA.
Corresponds to the JSON property emailPasswordEnforcementState
1439 1440 1441 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1439 def email_password_enforcement_state @email_password_enforcement_state end |
#managed_rules ⇒ Array<Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2RecaptchaManagedRule>
The managed rules for authentication action based on reCAPTCHA scores. The
rules are shared across providers for a given tenant project.
Corresponds to the JSON property managedRules
1445 1446 1447 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1445 def managed_rules @managed_rules end |
#phone_enforcement_state ⇒ String
The reCAPTCHA config for phone provider, containing the enforcement status.
The phone provider contains all SMS related user flows protected by reCAPTCHA.
Corresponds to the JSON property phoneEnforcementState
1451 1452 1453 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1451 def phone_enforcement_state @phone_enforcement_state end |
#recaptcha_keys ⇒ Array<Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2RecaptchaKey>
The reCAPTCHA keys.
Corresponds to the JSON property recaptchaKeys
1456 1457 1458 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1456 def recaptcha_keys @recaptcha_keys end |
#toll_fraud_managed_rules ⇒ Array<Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2RecaptchaTollFraudManagedRule>
The managed rules for the authentication action based on reCAPTCHA toll fraud
risk scores. Toll fraud managed rules will only take effect when the
phone_enforcement_state is AUDIT or ENFORCE and use_sms_toll_fraud_protection
is true.
Corresponds to the JSON property tollFraudManagedRules
1464 1465 1466 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1464 def toll_fraud_managed_rules @toll_fraud_managed_rules end |
#use_account_defender ⇒ Boolean Also known as: use_account_defender?
Whether to use the account defender for reCAPTCHA assessment. Defaults to
false.
Corresponds to the JSON property useAccountDefender
1470 1471 1472 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1470 def use_account_defender @use_account_defender end |
#use_sms_bot_score ⇒ Boolean Also known as: use_sms_bot_score?
Whether to use the rCE bot score for reCAPTCHA phone provider. Can only be
true when the phone_enforcement_state is AUDIT or ENFORCE.
Corresponds to the JSON property useSmsBotScore
1477 1478 1479 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1477 def use_sms_bot_score @use_sms_bot_score end |
#use_sms_toll_fraud_protection ⇒ Boolean Also known as: use_sms_toll_fraud_protection?
Whether to use the rCE sms toll fraud protection risk score for reCAPTCHA
phone provider. Can only be true when the phone_enforcement_state is AUDIT or
ENFORCE.
Corresponds to the JSON property useSmsTollFraudProtection
1485 1486 1487 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1485 def use_sms_toll_fraud_protection @use_sms_toll_fraud_protection end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1493 def update!(**args) @email_password_enforcement_state = args[:email_password_enforcement_state] if args.key?(:email_password_enforcement_state) @managed_rules = args[:managed_rules] if args.key?(:managed_rules) @phone_enforcement_state = args[:phone_enforcement_state] if args.key?(:phone_enforcement_state) @recaptcha_keys = args[:recaptcha_keys] if args.key?(:recaptcha_keys) @toll_fraud_managed_rules = args[:toll_fraud_managed_rules] if args.key?(:toll_fraud_managed_rules) @use_account_defender = args[:use_account_defender] if args.key?(:use_account_defender) @use_sms_bot_score = args[:use_sms_bot_score] if args.key?(:use_sms_bot_score) @use_sms_toll_fraud_protection = args[:use_sms_toll_fraud_protection] if args.key?(:use_sms_toll_fraud_protection) end |