Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2SendEmail
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2SendEmail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
Options for email sending.
Instance Attribute Summary collapse
-
#callback_uri ⇒ String
action url in email template.
-
#change_email_template ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailTemplate
Email template.
-
#dns_info ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2DnsInfo
Information of custom domain DNS verification.
-
#legacy_reset_password_template ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailTemplate
Email template.
-
#method_prop ⇒ String
The method used for sending an email.
-
#reset_password_template ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailTemplate
Email template.
-
#revert_second_factor_addition_template ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailTemplate
Email template.
-
#smtp ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2Smtp
Configuration for SMTP relay Corresponds to the JSON property
smtp. -
#verify_email_template ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailTemplate
Email template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2SendEmail
constructor
A new instance of GoogleCloudIdentitytoolkitAdminV2SendEmail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2SendEmail
Returns a new instance of GoogleCloudIdentitytoolkitAdminV2SendEmail.
1693 1694 1695 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#callback_uri ⇒ String
action url in email template.
Corresponds to the JSON property callbackUri
1625 1626 1627 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1625 def callback_uri @callback_uri end |
#change_email_template ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailTemplate
Email template. The subject and body fields can contain the following
placeholders which will be replaced with the appropriate values: %LINK% - The
link to use to redeem the send OOB code. %EMAIL% - The email where the email
is being sent. %NEW_EMAIL% - The new email being set for the account (when
applicable). %APP_NAME% - The Google Cloud project's display name. %
DISPLAY_NAME% - The user's display name.
Corresponds to the JSON property changeEmailTemplate
1635 1636 1637 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1635 def change_email_template @change_email_template end |
#dns_info ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2DnsInfo
Information of custom domain DNS verification. By default, default_domain will
be used. A custom domain can be configured using VerifyCustomDomain.
Corresponds to the JSON property dnsInfo
1641 1642 1643 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1641 def dns_info @dns_info end |
#legacy_reset_password_template ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailTemplate
Email template. The subject and body fields can contain the following
placeholders which will be replaced with the appropriate values: %LINK% - The
link to use to redeem the send OOB code. %EMAIL% - The email where the email
is being sent. %NEW_EMAIL% - The new email being set for the account (when
applicable). %APP_NAME% - The Google Cloud project's display name. %
DISPLAY_NAME% - The user's display name.
Corresponds to the JSON property legacyResetPasswordTemplate
1651 1652 1653 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1651 def legacy_reset_password_template @legacy_reset_password_template end |
#method_prop ⇒ String
The method used for sending an email.
Corresponds to the JSON property method
1656 1657 1658 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1656 def method_prop @method_prop end |
#reset_password_template ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailTemplate
Email template. The subject and body fields can contain the following
placeholders which will be replaced with the appropriate values: %LINK% - The
link to use to redeem the send OOB code. %EMAIL% - The email where the email
is being sent. %NEW_EMAIL% - The new email being set for the account (when
applicable). %APP_NAME% - The Google Cloud project's display name. %
DISPLAY_NAME% - The user's display name.
Corresponds to the JSON property resetPasswordTemplate
1666 1667 1668 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1666 def reset_password_template @reset_password_template end |
#revert_second_factor_addition_template ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailTemplate
Email template. The subject and body fields can contain the following
placeholders which will be replaced with the appropriate values: %LINK% - The
link to use to redeem the send OOB code. %EMAIL% - The email where the email
is being sent. %NEW_EMAIL% - The new email being set for the account (when
applicable). %APP_NAME% - The Google Cloud project's display name. %
DISPLAY_NAME% - The user's display name.
Corresponds to the JSON property revertSecondFactorAdditionTemplate
1676 1677 1678 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1676 def revert_second_factor_addition_template @revert_second_factor_addition_template end |
#smtp ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2Smtp
Configuration for SMTP relay
Corresponds to the JSON property smtp
1681 1682 1683 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1681 def smtp @smtp end |
#verify_email_template ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailTemplate
Email template. The subject and body fields can contain the following
placeholders which will be replaced with the appropriate values: %LINK% - The
link to use to redeem the send OOB code. %EMAIL% - The email where the email
is being sent. %NEW_EMAIL% - The new email being set for the account (when
applicable). %APP_NAME% - The Google Cloud project's display name. %
DISPLAY_NAME% - The user's display name.
Corresponds to the JSON property verifyEmailTemplate
1691 1692 1693 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1691 def verify_email_template @verify_email_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1698 def update!(**args) @callback_uri = args[:callback_uri] if args.key?(:callback_uri) @change_email_template = args[:change_email_template] if args.key?(:change_email_template) @dns_info = args[:dns_info] if args.key?(:dns_info) @legacy_reset_password_template = args[:legacy_reset_password_template] if args.key?(:legacy_reset_password_template) @method_prop = args[:method_prop] if args.key?(:method_prop) @reset_password_template = args[:reset_password_template] if args.key?(:reset_password_template) @revert_second_factor_addition_template = args[:revert_second_factor_addition_template] if args.key?(:revert_second_factor_addition_template) @smtp = args[:smtp] if args.key?(:smtp) @verify_email_template = args[:verify_email_template] if args.key?(:verify_email_template) end |