Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
Configures the regions where users are allowed to send verification SMS for the project or tenant. This is based on the calling code of the destination phone number.
Instance Attribute Summary collapse
-
#allow_by_default ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2AllowByDefault
Defines a policy of allowing every region by default and adding disallowed regions to a disallow list.
-
#allowlist_only ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2AllowlistOnly
Defines a policy of only allowing regions by explicitly adding them to an allowlist.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig
constructor
A new instance of GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig
Returns a new instance of GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig.
1800 1801 1802 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1800 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_by_default ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2AllowByDefault
Defines a policy of allowing every region by default and adding disallowed
regions to a disallow list.
Corresponds to the JSON property allowByDefault
1792 1793 1794 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1792 def allow_by_default @allow_by_default end |
#allowlist_only ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2AllowlistOnly
Defines a policy of only allowing regions by explicitly adding them to an
allowlist.
Corresponds to the JSON property allowlistOnly
1798 1799 1800 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1798 def allowlist_only @allowlist_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1805 1806 1807 1808 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1805 def update!(**args) @allow_by_default = args[:allow_by_default] if args.key?(:allow_by_default) @allowlist_only = args[:allowlist_only] if args.key?(:allowlist_only) end |