Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2Tenant
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2Tenant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
A Tenant contains configuration for the tenant in a multi-tenant project.
Instance Attribute Summary collapse
-
#allow_password_signup ⇒ Boolean
(also: #allow_password_signup?)
Whether to allow email/password user authentication.
-
#autodelete_anonymous_users ⇒ Boolean
(also: #autodelete_anonymous_users?)
Whether anonymous users will be auto-deleted after a period of 30 days.
-
#client ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2ClientPermissionConfig
Options related to how clients making requests on behalf of a tenant should be configured.
-
#disable_auth ⇒ Boolean
(also: #disable_auth?)
Whether authentication is disabled for the tenant.
-
#display_name ⇒ String
Display name of the tenant.
-
#email_privacy_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailPrivacyConfig
Configuration for settings related to email privacy and public visibility.
-
#enable_anonymous_user ⇒ Boolean
(also: #enable_anonymous_user?)
Whether to enable anonymous user authentication.
-
#enable_email_link_signin ⇒ Boolean
(also: #enable_email_link_signin?)
Whether to enable email link user authentication.
-
#hash_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2HashConfig
History information of the hash algorithm and key.
-
#inheritance ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2Inheritance
Settings that the tenants will inherit from project level.
-
#mfa_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig
Options related to MultiFactor Authentication for the project.
-
#mobile_links_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MobileLinksConfig
Configuration mobile links.
-
#monitoring ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MonitoringConfig
Configuration related to monitoring project activity.
-
#name ⇒ String
Output only.
-
#password_policy_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2PasswordPolicyConfig
The configuration for the password policy on the project.
-
#recaptcha_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2RecaptchaConfig
The reCAPTCHA Enterprise integration config.
-
#sms_region_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig
Configures the regions where users are allowed to send verification SMS for the project or tenant.
-
#test_phone_numbers ⇒ Hash<String,String>
A map of pairs that can be used for MFA.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2Tenant
constructor
A new instance of GoogleCloudIdentitytoolkitAdminV2Tenant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitAdminV2Tenant
Returns a new instance of GoogleCloudIdentitytoolkitAdminV2Tenant.
2083 2084 2085 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2083 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_password_signup ⇒ Boolean Also known as: allow_password_signup?
Whether to allow email/password user authentication.
Corresponds to the JSON property allowPasswordSignup
1980 1981 1982 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1980 def allow_password_signup @allow_password_signup end |
#autodelete_anonymous_users ⇒ Boolean Also known as: autodelete_anonymous_users?
Whether anonymous users will be auto-deleted after a period of 30 days.
Corresponds to the JSON property autodeleteAnonymousUsers
1986 1987 1988 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1986 def autodelete_anonymous_users @autodelete_anonymous_users end |
#client ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2ClientPermissionConfig
Options related to how clients making requests on behalf of a tenant should be
configured.
Corresponds to the JSON property client
1993 1994 1995 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 1993 def client @client end |
#disable_auth ⇒ Boolean Also known as: disable_auth?
Whether authentication is disabled for the tenant. If true, the users under
the disabled tenant are not allowed to sign-in. Admins of the disabled tenant
are not able to manage its users.
Corresponds to the JSON property disableAuth
2000 2001 2002 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2000 def disable_auth @disable_auth end |
#display_name ⇒ String
Display name of the tenant.
Corresponds to the JSON property displayName
2006 2007 2008 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2006 def display_name @display_name end |
#email_privacy_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2EmailPrivacyConfig
Configuration for settings related to email privacy and public visibility.
Settings in this config protect against email enumeration, but may make some
trade-offs in user-friendliness.
Corresponds to the JSON property emailPrivacyConfig
2013 2014 2015 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2013 def email_privacy_config @email_privacy_config end |
#enable_anonymous_user ⇒ Boolean Also known as: enable_anonymous_user?
Whether to enable anonymous user authentication.
Corresponds to the JSON property enableAnonymousUser
2018 2019 2020 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2018 def enable_anonymous_user @enable_anonymous_user end |
#enable_email_link_signin ⇒ Boolean Also known as: enable_email_link_signin?
Whether to enable email link user authentication.
Corresponds to the JSON property enableEmailLinkSignin
2024 2025 2026 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2024 def enable_email_link_signin @enable_email_link_signin end |
#hash_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2HashConfig
History information of the hash algorithm and key. Different accounts'
passwords may be generated by different version.
Corresponds to the JSON property hashConfig
2031 2032 2033 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2031 def hash_config @hash_config end |
#inheritance ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2Inheritance
Settings that the tenants will inherit from project level.
Corresponds to the JSON property inheritance
2036 2037 2038 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2036 def inheritance @inheritance end |
#mfa_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig
Options related to MultiFactor Authentication for the project.
Corresponds to the JSON property mfaConfig
2041 2042 2043 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2041 def mfa_config @mfa_config end |
#mobile_links_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MobileLinksConfig
Configuration mobile links.
Corresponds to the JSON property mobileLinksConfig
2046 2047 2048 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2046 def mobile_links_config @mobile_links_config end |
#monitoring ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2MonitoringConfig
Configuration related to monitoring project activity.
Corresponds to the JSON property monitoring
2051 2052 2053 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2051 def monitoring @monitoring end |
#name ⇒ String
Output only. Resource name of a tenant. For example: "projects/project-id/
tenants/tenant-id"
Corresponds to the JSON property name
2057 2058 2059 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2057 def name @name end |
#password_policy_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2PasswordPolicyConfig
The configuration for the password policy on the project.
Corresponds to the JSON property passwordPolicyConfig
2062 2063 2064 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2062 def password_policy_config @password_policy_config end |
#recaptcha_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2RecaptchaConfig
The reCAPTCHA Enterprise integration config.
Corresponds to the JSON property recaptchaConfig
2067 2068 2069 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2067 def recaptcha_config @recaptcha_config end |
#sms_region_config ⇒ Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig
Configures the regions where users are allowed to send verification SMS for
the project or tenant. This is based on the calling code of the destination
phone number.
Corresponds to the JSON property smsRegionConfig
2074 2075 2076 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2074 def sms_region_config @sms_region_config end |
#test_phone_numbers ⇒ Hash<String,String>
A map of pairs that can be used for MFA. The phone number should be in E.164
format (https://www.itu.int/rec/T-REC-E.164/) and a maximum of 10 pairs can be
added (error will be thrown once exceeded).
Corresponds to the JSON property testPhoneNumbers
2081 2082 2083 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2081 def test_phone_numbers @test_phone_numbers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2088 def update!(**args) @allow_password_signup = args[:allow_password_signup] if args.key?(:allow_password_signup) @autodelete_anonymous_users = args[:autodelete_anonymous_users] if args.key?(:autodelete_anonymous_users) @client = args[:client] if args.key?(:client) @disable_auth = args[:disable_auth] if args.key?(:disable_auth) @display_name = args[:display_name] if args.key?(:display_name) @email_privacy_config = args[:email_privacy_config] if args.key?(:email_privacy_config) @enable_anonymous_user = args[:enable_anonymous_user] if args.key?(:enable_anonymous_user) @enable_email_link_signin = args[:enable_email_link_signin] if args.key?(:enable_email_link_signin) @hash_config = args[:hash_config] if args.key?(:hash_config) @inheritance = args[:inheritance] if args.key?(:inheritance) @mfa_config = args[:mfa_config] if args.key?(:mfa_config) @mobile_links_config = args[:mobile_links_config] if args.key?(:mobile_links_config) @monitoring = args[:monitoring] if args.key?(:monitoring) @name = args[:name] if args.key?(:name) @password_policy_config = args[:password_policy_config] if args.key?(:password_policy_config) @recaptcha_config = args[:recaptcha_config] if args.key?(:recaptcha_config) @sms_region_config = args[:sms_region_config] if args.key?(:sms_region_config) @test_phone_numbers = args[:test_phone_numbers] if args.key?(:test_phone_numbers) end |