Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2RevokeTokenRequest
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2RevokeTokenRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
Request message for RevokeToken.
Instance Attribute Summary collapse
-
#id_token ⇒ String
Required.
-
#provider_id ⇒ String
Required.
-
#redirect_uri ⇒ String
The redirect URI provided in the initial authorization request made by the client to the IDP.
-
#tenant_id ⇒ String
The ID of the Identity Platform tenant the user is signing in to.
-
#token ⇒ String
Required.
-
#token_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2RevokeTokenRequest
constructor
A new instance of GoogleCloudIdentitytoolkitV2RevokeTokenRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2RevokeTokenRequest
Returns a new instance of GoogleCloudIdentitytoolkitV2RevokeTokenRequest.
2664 2665 2666 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2664 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id_token ⇒ String
Required. A valid Identity Platform ID token to link the account. If there was
a successful token revocation request on the account and no tokens are
generated after the revocation, the duplicate requests will be ignored and
returned immediately.
Corresponds to the JSON property idToken
2631 2632 2633 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2631 def id_token @id_token end |
#provider_id ⇒ String
Required. The idp provider for the token. Currently only supports Apple Idp.
The format should be "apple.com".
Corresponds to the JSON property providerId
2637 2638 2639 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2637 def provider_id @provider_id end |
#redirect_uri ⇒ String
The redirect URI provided in the initial authorization request made by the
client to the IDP. The URI must use the HTTPS protocol, include a domain name,
and can't contain an IP address or localhost. Required if token_type is CODE.
Corresponds to the JSON property redirectUri
2644 2645 2646 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2644 def redirect_uri @redirect_uri end |
#tenant_id ⇒ String
The ID of the Identity Platform tenant the user is signing in to. If not set,
the user will sign in to the default Identity Platform project.
Corresponds to the JSON property tenantId
2650 2651 2652 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2650 def tenant_id @tenant_id end |
#token ⇒ String
Required. The token to be revoked. If an authorization_code is passed in, the
API will first exchange the code for access token and then revoke the token
exchanged.
Corresponds to the JSON property token
2657 2658 2659 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2657 def token @token end |
#token_type ⇒ String
Required. The type of the token to be revoked.
Corresponds to the JSON property tokenType
2662 2663 2664 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2662 def token_type @token_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2669 2670 2671 2672 2673 2674 2675 2676 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2669 def update!(**args) @id_token = args[:id_token] if args.key?(:id_token) @provider_id = args[:provider_id] if args.key?(:provider_id) @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri) @tenant_id = args[:tenant_id] if args.key?(:tenant_id) @token = args[:token] if args.key?(:token) @token_type = args[:token_type] if args.key?(:token_type) end |