Class: Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2StartMfaTotpEnrollmentResponseInfo
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV2::GoogleCloudIdentitytoolkitV2StartMfaTotpEnrollmentResponseInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v2/classes.rb,
lib/google/apis/identitytoolkit_v2/representations.rb,
lib/google/apis/identitytoolkit_v2/representations.rb
Overview
Mfa response info specific to TOTP auth for StartMfa.
Instance Attribute Summary collapse
-
#finalize_enrollment_time ⇒ String
The time by which the enrollment must finish.
-
#hashing_algorithm ⇒ String
The hashing algorithm used to generate the verification code.
-
#period_sec ⇒ Fixnum
Duration in seconds at which the verification code will change.
-
#session_info ⇒ String
An encoded string that represents the enrollment session.
-
#shared_secret_key ⇒ String
A base 32 encoded string that represents the shared TOTP secret.
-
#verification_code_length ⇒ Fixnum
The length of the verification code that needs to be generated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2StartMfaTotpEnrollmentResponseInfo
constructor
A new instance of GoogleCloudIdentitytoolkitV2StartMfaTotpEnrollmentResponseInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV2StartMfaTotpEnrollmentResponseInfo
Returns a new instance of GoogleCloudIdentitytoolkitV2StartMfaTotpEnrollmentResponseInfo.
2964 2965 2966 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#finalize_enrollment_time ⇒ String
The time by which the enrollment must finish.
Corresponds to the JSON property finalizeEnrollmentTime
2933 2934 2935 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2933 def finalize_enrollment_time @finalize_enrollment_time end |
#hashing_algorithm ⇒ String
The hashing algorithm used to generate the verification code.
Corresponds to the JSON property hashingAlgorithm
2938 2939 2940 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2938 def hashing_algorithm @hashing_algorithm end |
#period_sec ⇒ Fixnum
Duration in seconds at which the verification code will change.
Corresponds to the JSON property periodSec
2943 2944 2945 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2943 def period_sec @period_sec end |
#session_info ⇒ String
An encoded string that represents the enrollment session.
Corresponds to the JSON property sessionInfo
2948 2949 2950 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2948 def session_info @session_info end |
#shared_secret_key ⇒ String
A base 32 encoded string that represents the shared TOTP secret. The base 32
encoding is the one specified by RFC4648#section-6. (This is the same as the base 32 encoding
from RFC3548#section-5.)
Corresponds to the JSON property sharedSecretKey
2957 2958 2959 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2957 def shared_secret_key @shared_secret_key end |
#verification_code_length ⇒ Fixnum
The length of the verification code that needs to be generated.
Corresponds to the JSON property verificationCodeLength
2962 2963 2964 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2962 def verification_code_length @verification_code_length end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2969 2970 2971 2972 2973 2974 2975 2976 |
# File 'lib/google/apis/identitytoolkit_v2/classes.rb', line 2969 def update!(**args) @finalize_enrollment_time = args[:finalize_enrollment_time] if args.key?(:finalize_enrollment_time) @hashing_algorithm = args[:hashing_algorithm] if args.key?(:hashing_algorithm) @period_sec = args[:period_sec] if args.key?(:period_sec) @session_info = args[:session_info] if args.key?(:session_info) @shared_secret_key = args[:shared_secret_key] if args.key?(:shared_secret_key) @verification_code_length = args[:verification_code_length] if args.key?(:verification_code_length) end |